@@ -2,4 +2,4 @@ from .base import Api
 from .data import JsonApiObject
 from . import orm
 
-__all__ = [Api, JsonApiObject, orm]
+__all__ = ['Api', 'JsonApiObject', 'orm']
